==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/AccessPolicyRuleActions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AccessPolicyRuleApplicationSignOn;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AccessPolicyRuleActions
 */
@JsonPropertyOrder({ AccessPolicyRuleActions.JSON_PROPERTY_APP_SIGN_ON })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class AccessPolicyRuleActions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_APP_SIGN_ON = "appSignOn";
    private AccessPolicyRuleApplicationSignOn appSignOn;

    public AccessPolicyRuleActions() {
    }

    public AccessPolicyRuleActions appSignOn(AccessPolicyRuleApplicationSignOn appSignOn) {

        this.appSignOn = appSignOn;
        return this;
    }

    /**
     * Get appSignOn
     *
     * @return appSignOn
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_APP_SIGN_ON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AccessPolicyRuleApplicationSignOn getAppSignOn() {
        return appSignOn;
    }

    @JsonProperty(JSON_PROPERTY_APP_SIGN_ON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAppSignOn(AccessPolicyRuleApplicationSignOn appSignOn) {
        this.appSignOn = appSignOn;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AccessPolicyRuleActions accessPolicyRuleActions = (AccessPolicyRuleActions) o;
        return Objects.equals(this.appSignOn, accessPolicyRuleActions.appSignOn);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(appSignOn);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AccessPolicyRuleActions {\n");
        sb.append("    appSignOn: ").append(toIndentedString(appSignOn)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/AccessPolicyRuleActions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AccessPolicyRuleApplicationSignOn;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AccessPolicyRuleActions
 */
@JsonPropertyOrder({ AccessPolicyRuleActions.JSON_PROPERTY_APP_SIGN_ON })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class AccessPolicyRuleActions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_APP_SIGN_ON = "appSignOn";
    private AccessPolicyRuleApplicationSignOn appSignOn;

    public AccessPolicyRuleActions() {
    }

    public AccessPolicyRuleActions appSignOn(AccessPolicyRuleApplicationSignOn appSignOn) {

        this.appSignOn = appSignOn;
        return this;
    }

    /**
     * Get appSignOn
     *
     * @return appSignOn
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_APP_SIGN_ON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AccessPolicyRuleApplicationSignOn getAppSignOn() {
        return appSignOn;
    }

    @JsonProperty(JSON_PROPERTY_APP_SIGN_ON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAppSignOn(AccessPolicyRuleApplicationSignOn appSignOn) {
        this.appSignOn = appSignOn;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AccessPolicyRuleActions accessPolicyRuleActions = (AccessPolicyRuleActions) o;
        return Objects.equals(this.appSignOn, accessPolicyRuleActions.appSignOn);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(appSignOn);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AccessPolicyRuleActions {\n");
        sb.append("    appSignOn: ").append(toIndentedString(appSignOn)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
